#[ext]Expand description
A lightweight attribute macro for easily writing extension trait pattern.
See the crate-level documentation for details.
#[ext]A lightweight attribute macro for easily writing extension trait pattern.
See the crate-level documentation for details.